cgexplore.terms.MartiniBondRange
================================

.. currentmodule:: cgexplore.terms

.. autoclass:: MartiniBondRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~MartiniBondRange.yield_bonds
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MartiniBondRange.type1
      ~MartiniBondRange.type2
      ~MartiniBondRange.element1
      ~MartiniBondRange.element2
      ~MartiniBondRange.funct
      ~MartiniBondRange.bond_rs
      ~MartiniBondRange.bond_ks
   
   